@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import os
@@ -93,6 +92,6 @@ def asciidoc_command_list(commands, f):
         _write_underlined(kind, '~', f)
         f.write('\n')
         for cmd, help in cmds:
-            f.write('linkstgsub:%s[]::\n' % cmd)
+            f.write('linkstg:%s[]::\n' % cmd)
             f.write('    %s\n' % help)
         f.write('\n')
