@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os, time, re
@@ -154,7 +153,7 @@ def __delete_branch(doomed_name, force = False):
 def __cleanup_branch(name, force = False):
     branch = stack.Series(name)
     if branch.get_protected():
-        raise CmdExcpetion('This branch is protected. Clean up is not permitted')
+        raise CmdException('This branch is protected. Clean up is not permitted')
 
     out.start('Cleaning up branch "%s"' % name)
     branch.delete(force = force, cleanup = True)
