@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os, os.path, re, email.Utils
@@ -476,6 +475,25 @@ def readonly_constant_property(f):
         return getattr(self, n)
     return property(new_f)
 
+def run_commit_msg_hook(repo, cd, editor_is_used=True):
+    """Run the commit-msg hook (if any) on a commit.
+
+    @param cd: The L{CommitData<stgit.lib.git.CommitData>} to run the
+               hook on.
+
+    Return the new L{CommitData<stgit.lib.git.CommitData>}."""
+    env = dict(cd.env)
+    if not editor_is_used:
+        env['GIT_EDITOR'] = ':'
+    commit_msg_hook = get_hook(repo, 'commit-msg', env)
+
+    try:
+        new_msg = run_hook_on_string(commit_msg_hook, cd.message)
+    except RunException, exc:
+        raise EditorException, str(exc)
+
+    return cd.set_message(new_msg)
+
 def update_commit_data(cd, options):
     """Return a new CommitData object updated according to the command line
     options."""
