@@ -12,8 +12,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 from stgit.argparse import opt
@@ -23,7 +22,7 @@ from stgit import argparse
 
 help = 'Delete patches'
 kind = 'patch'
-usage = ['[options] <patch1> [<patch2>] [<patch3>..<patch4>]']
+usage = ['[options] [--] <patch1> [<patch2>] [<patch3>..<patch4>]']
 description = """
 Delete the patches passed as arguments."""
 
@@ -38,7 +37,9 @@ options = [
         worktree. This can be useful e.g. if you want to split a patch
         into several smaller pieces."""),
     opt('-b', '--branch', args = [argparse.stg_branches],
-        short = 'Use BRANCH instead of the default branch')]
+        short = 'Use BRANCH instead of the default branch'),
+    opt('-t', '--top', action = 'store_true',
+        short = 'Delete top patch'),]
 
 directory = common.DirectoryHasRepositoryLib()
 
@@ -49,9 +50,17 @@ def func(parser, options, args):
         iw = None # can't use index/workdir to manipulate another branch
     else:
         iw = stack.repository.default_iw
-    if args:
+    if args and options.top:
+        parser.error('Either --top or patches must be specified')
+    elif args:
         patches = set(common.parse_patches(args, list(stack.patchorder.all),
                                            len(stack.patchorder.applied)))
+    elif options.top:
+        applied = stack.patchorder.applied
+        if applied:
+            patches = set([applied[-1]])
+        else:
+            raise common.CmdException, 'No patches applied'
     else:
         parser.error('No patches specified')
 
