@@ -12,8 +12,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os
@@ -27,7 +26,7 @@ from stgit.lib import git as gitlib
 
 help = 'Show the tree diff'
 kind = 'wc'
-usage = ['[options] [<files or dirs>]']
+usage = ['[options] [--] [<files or dirs>]']
 description = """
 Show the diff (default) or diffstat between the current working copy
 or a tree-ish object and another tree-ish object (defaulting to HEAD).
