@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os, re, email, tarfile
@@ -27,7 +26,7 @@ from stgit import argparse, stack, git
 name = 'import'
 help = 'Import a GNU diff file as a new patch'
 kind = 'patch'
-usage = ['[options] [<file>|<url>]']
+usage = ['[options] [--] [<file>|<url>]']
 description = """
 Create a new patch and apply the given GNU diff file (or the standard
 input). By default, the file name is used as the patch name but this
@@ -243,6 +242,16 @@ def __import_series(filename, options):
         patch = re.sub('#.*$', '', line).strip()
         if not patch:
             continue
+        # Quilt can have "-p0", "-p1" or "-pab" patches stacked in the
+        # series but as strip level default to 1, only "-p0" can actually
+        # be found in the series file, the other ones are implicit
+        m = re.match(r'(?P<patchfilename>.*)\s+-p\s*(?P<striplevel>(\d+|ab)?)\s*$', patch)
+        options.strip = 1
+        if m:
+            patch = m.group('patchfilename')
+            if m.group('striplevel') != '0':
+                raise CmdException, "error importing quilt series, patch '%s' has unsupported strip level: '-p%s'" % (patch, m.group('striplevel'))
+            options.strip = 0
         patchfile = os.path.join(patchdir, patch)
         patch = __replace_slashes_with_dashes(patch);
 
