@@ -12,28 +12,24 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
-import sys, os
-from optparse import OptionParser, make_option
+from stgit.commands import common
+from stgit.lib import stack
 
-from stgit.commands.common import *
-from stgit.utils import *
-from stgit import stack, git
+help = 'Initialise the current branch for use with StGIT'
+kind = 'stack'
+usage = ['']
+description = """
+Initialise the current git branch to be used as an StGIT stack. The
+branch (and the git repository it is in) must already exist and
+contain at least one commit."""
 
-
-help = 'initialise the current branch for use with StGIT'
-usage = """%prog [options]
-
-Initialise the current GIT branch to be used as an StGIT stack. Note
-that you must already be in a GIT repository and .git/HEAD must point
-to a valid file in refs/heads/."""
-
-directory = DirectoryHasRepository()
+args = []
 options = []
 
+directory = common.DirectoryHasRepositoryLib()
 
 def func(parser, options, args):
     """Performs the repository initialisation
@@ -41,4 +37,4 @@ def func(parser, options, args):
     if len(args) != 0:
         parser.error('incorrect number of arguments')
 
-    crt_series.init()
+    stack.Stack.initialise(directory.repository)
