@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import os.path
@@ -28,7 +27,7 @@ from stgit.out import out
 
 help = 'Display the patch changelog'
 kind = 'stack'
-usage = ['[options] [<patches>]']
+usage = ['[options] [--] [<patches>]']
 description = """
 List the history of the patch stack: the stack log. If one or more
 patch names are given, limit the list to the log entries that touch
