@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os
@@ -118,6 +117,8 @@ def __pick_commit(commit_id, patchname, options):
             message = 'Revert "%s"\n\nThis reverts commit %s.\n\n%s\n' \
                     % (subject, commit.get_id_hash(), body)
         elif options.expose:
+            if not message.endswith('\n'):
+                message += '\n'
             message += '(imported from commit %s)\n' % commit.get_id_hash()
         author_name, author_email, author_date = \
                      name_email_date(commit.get_author())
