@@ -12,8 +12,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 from stgit.commands import common
@@ -23,7 +22,7 @@ from stgit.argparse import opt
 
 help = 'Pop one or more patches from the stack'
 kind = 'stack'
-usage = ['[options] [<patch1>] [<patch2>] [<patch3>..<patch4>]']
+usage = ['[options] [--] [<patch1>] [<patch2>] [<patch3>..<patch4>]']
 description = """
 Pop the topmost patch or a range of patches from the stack. The
 command fails if there are conflicts or local changes (and --keep was
@@ -38,8 +37,13 @@ args = [argparse.patch_range(argparse.applied_patches)]
 options = [
     opt('-a', '--all', action = 'store_true',
         short = 'Pop all the applied patches'),
+    opt('-s', '--spill', action = 'store_true',
+        short = 'Pop a patch, keeping its modifications in the tree'),
     opt('-n', '--number', type = 'int',
-        short = 'Pop the specified number of patches')
+        short = 'Pop the specified number of patches', long = '''
+        Pop the specified number of patches.
+
+        With a negative number, pop all but that many patches.'''),
     ] + argparse.keep_option()
 
 directory = common.DirectoryHasRepositoryLib()
@@ -48,16 +52,20 @@ def func(parser, options, args):
     """Pop the given patches or the topmost one from the stack."""
     stack = directory.repository.current_stack
     iw = stack.repository.default_iw
-    clean_iw = (not options.keep and iw) or None
+    clean_iw = (not options.keep and not options.spill and iw) or None
     trans = transaction.StackTransaction(stack, 'pop',
                                          check_clean_iw = clean_iw)
 
+    if options.number == 0:
+        # explicitly allow this without any warning/error message
+        return
+
     if not trans.applied:
         raise common.CmdException('No patches applied')
 
     if options.all:
         patches = trans.applied
-    elif options.number:
+    elif options.number is not None:
         # reverse it twice to also work with negative or bigger than
         # the length numbers
         patches = trans.applied[::-1][:options.number][::-1]
@@ -67,12 +75,19 @@ def func(parser, options, args):
         patches = common.parse_patches(args, trans.applied, ordered = True)
 
     if not patches:
+		#FIXME: Why is this an error, and not just a noop ?
         raise common.CmdException('No patches to pop')
 
+    if options.spill:
+        if set(stack.patchorder.applied[-len(patches):]) != set(patches):
+            parser.error('Can only spill topmost applied patches')
+        iw = None # don't touch index+worktree
+
     applied = [p for p in trans.applied if not p in set(patches)]
     unapplied = patches + trans.unapplied
     try:
-        trans.reorder_patches(applied, unapplied, iw = iw)
+        trans.reorder_patches(applied, unapplied, iw = iw,
+                              allow_interactive = True)
     except transaction.TransactionException:
         pass
     return trans.run(iw)
