@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os
@@ -25,7 +24,7 @@ from stgit import argparse, stack, git
 
 help = 'Pull changes from a remote repository'
 kind = 'stack'
-usage = ['[options] [<repository>]']
+usage = ['[options] [--] [<repository>]']
 description = """
 Pull the latest changes from the given remote repository (defaulting
 to branch.<name>.remote, or 'origin' if not set). This command works
