@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os
@@ -23,7 +22,7 @@ from stgit import argparse, stack, git
 
 help = 'Move the stack base to another point in history'
 kind = 'stack'
-usage = ['[options] <new-base-id>']
+usage = ['[options] [--] <new-base-id>']
 description = """
 Pop all patches from current stack, move the stack base to the given
 <new-base-id> and push the patches back.
