@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 from stgit.argparse import opt
@@ -72,6 +71,7 @@ options = [
     opt('-a', '--annotate', metavar = 'NOTE',
         short = 'Annotate the patch log entry')
     ] + (argparse.message_options(save_template = False) +
+         argparse.hook_options() +
          argparse.sign_options() + argparse.author_options())
 
 directory = common.DirectoryHasRepositoryLib()
@@ -266,6 +266,7 @@ def func(parser, options, args):
     if retval != utils.STGIT_SUCCESS:
         return retval
     def edit_fun(cd):
+        orig_msg = cd.message
         cd, failed_diff = edit.auto_edit_patch(
             stack.repository, cd, msg = options.message, contains_diff = False,
             author = options.author, committer = lambda p: p,
@@ -276,6 +277,8 @@ def func(parser, options, args):
                 stack.repository, cd, edit_diff = False,
                 diff_flags = [], replacement_diff = None)
             assert not failed_diff
+        if not options.no_verify and (options.edit or cd.message != orig_msg):
+            cd = common.run_commit_msg_hook(stack.repository, cd, options.edit)
         return cd
     return absorb(stack, patch_name, temp_name, edit_fun,
                   annotate = options.annotate)
