@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os
@@ -24,7 +23,7 @@ from stgit import argparse, stack, git
 
 help = 'Rename a patch'
 kind = 'patch'
-usage = ['[options] [oldpatch] <newpatch>']
+usage = ['[options] [--] [oldpatch] <newpatch>']
 description = """
 Rename <oldpatch> into <newpatch> in a series. If <oldpatch> is not
 given, the top-most patch will be renamed."""
