@@ -11,8 +11,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 from stgit.commands import common
@@ -22,7 +21,7 @@ from stgit.argparse import opt
 
 help = 'Unhide a hidden patch'
 kind = 'stack'
-usage = ['[options] <patch-range>']
+usage = ['[options] [--] <patch-range>']
 description = """
 Unhide a hidden range of patches so that they are shown in the plain
 'stg series' command output."""
@@ -37,7 +36,7 @@ directory = common.DirectoryHasRepositoryLib()
 def func(parser, options, args):
     """Unhide a range of patch in the series."""
     stack = directory.repository.current_stack
-    trans = transaction.StackTransaction(stack, 'hide')
+    trans = transaction.StackTransaction(stack, 'unhide')
 
     if not args:
         parser.error('No patches specified')
