@@ -14,8 +14,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os, re
@@ -865,14 +864,14 @@ def refspec_localpart(refspec):
     if m:
         return m.group(1)
     else:
-        raise GitException, 'Cannot parse refspec "%s"' % line
+        raise GitException('Cannot parse refspec "%s"' % refspec)
 
 def refspec_remotepart(refspec):
     m = re.match('^([^:]*):[^:]*$', refspec)
     if m:
         return m.group(1)
     else:
-        raise GitException, 'Cannot parse refspec "%s"' % line
+        raise GitException('Cannot parse refspec "%s"' % refspec)
 
 def __remotes_from_config():
     return config.sections_matching(r'remote\.(.*)\.url')
