@@ -1,7 +1,7 @@
 """A Python class hierarchy wrapping a git repository and its
 contents."""
 
-import os, os.path, re
+import atexit, os, os.path, re, signal
 from datetime import datetime, timedelta, tzinfo
 
 from stgit import exception, run, utils
@@ -87,6 +87,32 @@ class TimeZone(tzinfo, Repr):
     def __str__(self):
         return self.__name
 
+def system_date(datestring):
+    m = re.match(r"^(.+)([+-]\d\d:?\d\d)$", datestring)
+    if m:
+        # Time zone included; we parse it ourselves, since "date"
+        # would convert it to the local time zone.
+        (ds, z) = m.groups()
+        try:
+            t = run.Run("date", "+%Y-%m-%d-%H-%M-%S", "-d", ds
+                        ).output_one_line()
+        except run.RunException:
+            return None
+    else:
+        # Time zone not included; we ask "date" to provide it for us.
+        try:
+            d = run.Run("date", "+%Y-%m-%d-%H-%M-%S_%z", "-d", datestring
+                        ).output_one_line()
+        except run.RunException:
+            return None
+        (t, z) = d.split("_")
+    year, month, day, hour, minute, second = [int(x) for x in t.split("-")]
+    try:
+        return datetime(year, month, day, hour, minute, second,
+                        tzinfo=TimeZone(z))
+    except ValueError:
+        raise DateException(datestring, "date")
+
 class Date(Immutable, Repr):
     """Represents a timestamp used in git commits."""
     def __init__(self, datestring):
@@ -112,6 +138,12 @@ class Date(Immutable, Repr):
                 raise DateException(datestring, 'date')
             return
 
+        # Try parsing with the system's "date" command.
+        sd = system_date(datestring)
+        if sd:
+            self.__time = sd
+            return
+
         raise DateException(datestring, 'date')
     def __str__(self):
         return self.isoformat()
@@ -327,6 +359,17 @@ class CommitData(Immutable, Repr):
         self.__author = d(author, 'author', Person.author)
         self.__committer = d(committer, 'committer', Person.committer)
         self.__message = d(message, 'message')
+    @property
+    def env(self):
+        env = {}
+        for p, v1 in ((self.author, 'AUTHOR'),
+                       (self.committer, 'COMMITTER')):
+            if p != None:
+                for attr, v2 in (('name', 'NAME'), ('email', 'EMAIL'),
+                                 ('date', 'DATE')):
+                    if getattr(p, attr) != None:
+                        env['GIT_%s_%s' % (v1, v2)] = str(getattr(p, attr))
+        return env
     tree = property(lambda self: self.__tree)
     parents = property(lambda self: self.__parents)
     @property
@@ -373,16 +416,8 @@ class CommitData(Immutable, Repr):
         for p in self.parents:
             c.append('-p')
             c.append(p.sha1)
-        env = {}
-        for p, v1 in ((self.author, 'AUTHOR'),
-                       (self.committer, 'COMMITTER')):
-            if p != None:
-                for attr, v2 in (('name', 'NAME'), ('email', 'EMAIL'),
-                                 ('date', 'DATE')):
-                    if getattr(p, attr) != None:
-                        env['GIT_%s_%s' % (v1, v2)] = str(getattr(p, attr))
-        sha1 = repository.run(c, env = env).raw_input(self.message
-                                                      ).output_one_line()
+        sha1 = repository.run(c, env = self.env).raw_input(self.message
+                                                           ).output_one_line()
         return repository.get_commit(sha1)
     @classmethod
     def parse(cls, repository, s):
@@ -390,23 +425,31 @@ class CommitData(Immutable, Repr):
         @return: A new L{CommitData} object
         @rtype: L{CommitData}"""
         cd = cls(parents = [])
-        lines = list(s.splitlines(True))
-        for i in xrange(len(lines)):
-            line = lines[i].strip()
+        lines = []
+        raw_lines = s.split('\n')
+        # Collapse multi-line header lines
+        for i, line in enumerate(raw_lines):
             if not line:
-                return cd.set_message(''.join(lines[i+1:]))
-            key, value = line.split(None, 1)
-            if key == 'tree':
-                cd = cd.set_tree(repository.get_tree(value))
-            elif key == 'parent':
-                cd = cd.add_parent(repository.get_commit(value))
-            elif key == 'author':
-                cd = cd.set_author(Person.parse(value))
-            elif key == 'committer':
-                cd = cd.set_committer(Person.parse(value))
+                cd = cd.set_message('\n'.join(raw_lines[i+1:]))
+                break
+            if line.startswith(' '):
+                # continuation line
+                lines[-1] += '\n' + line[1:]
             else:
-                assert False
-        assert False
+                lines.append(line)
+        for line in lines:
+            if ' ' in line:
+                key, value = line.split(' ', 1)
+                if key == 'tree':
+                    cd = cd.set_tree(repository.get_tree(value))
+                elif key == 'parent':
+                    cd = cd.add_parent(repository.get_commit(value))
+                elif key == 'author':
+                    cd = cd.set_author(Person.parse(value))
+                elif key == 'committer':
+                    cd = cd.set_committer(Person.parse(value))
+        return cd
+
 
 class Commit(GitObject):
     """Represents a git commit object. All the actual data contents of the
@@ -437,7 +480,14 @@ class Refs(object):
     def __cache_refs(self):
         """(Re-)Build the cache of all refs in the repository."""
         self.__refs = {}
-        for line in self.__repository.run(['git', 'show-ref']).output_lines():
+        runner = self.__repository.run(['git', 'show-ref'])
+        try:
+            lines = runner.output_lines()
+        except run.RunException:
+            # as this happens both in non-git trees and empty git
+            # trees, we silently ignore this error
+            return
+        for line in lines:
             m = re.match(r'^([0-9a-f]{40})\s+(\S+)$', line)
             sha1, ref = m.groups()
             self.__refs[ref] = sha1
@@ -520,6 +570,72 @@ class RunWithEnvCwd(RunWithEnv):
         @param args: Command and argument vector"""
         return RunWithEnv.run(self, args, self.env_in_cwd)
 
+class CatFileProcess(object):
+    def __init__(self, repo):
+        self.__repo = repo
+        self.__proc = None
+        atexit.register(self.__shutdown)
+    def __get_process(self):
+        if not self.__proc:
+            self.__proc = self.__repo.run(['git', 'cat-file', '--batch']
+                                          ).run_background()
+        return self.__proc
+    def __shutdown(self):
+        p = self.__proc
+        if p:
+            p.stdin.close()
+            os.kill(p.pid(), signal.SIGTERM)
+            p.wait()
+    def cat_file(self, sha1):
+        p = self.__get_process()
+        p.stdin.write('%s\n' % sha1)
+        p.stdin.flush()
+
+        # Read until we have the entire status line.
+        s = ''
+        while not '\n' in s:
+            s += os.read(p.stdout.fileno(), 4096)
+        h, b = s.split('\n', 1)
+        if h == '%s missing' % sha1:
+            raise SomeException()
+        hash, type, length = h.split()
+        assert hash == sha1
+        length = int(length)
+
+        # Read until we have the entire object plus the trailing
+        # newline.
+        while len(b) < length + 1:
+            b += os.read(p.stdout.fileno(), 4096)
+        return type, b[:-1]
+
+class DiffTreeProcesses(object):
+    def __init__(self, repo):
+        self.__repo = repo
+        self.__procs = {}
+        atexit.register(self.__shutdown)
+    def __get_process(self, args):
+        args = tuple(args)
+        if not args in self.__procs:
+            self.__procs[args] = self.__repo.run(
+                ['git', 'diff-tree', '--stdin'] + list(args)).run_background()
+        return self.__procs[args]
+    def __shutdown(self):
+        for p in self.__procs.values():
+            os.kill(p.pid(), signal.SIGTERM)
+            p.wait()
+    def diff_trees(self, args, sha1a, sha1b):
+        p = self.__get_process(args)
+        query = '%s %s\n' % (sha1a, sha1b)
+        end = 'EOF\n' # arbitrary string that's not a 40-digit hex number
+        p.stdin.write(query + end)
+        p.stdin.flush()
+        s = ''
+        while not (s.endswith('\n' + end) or s.endswith('\0' + end)):
+            s += os.read(p.stdout.fileno(), 4096)
+        assert s.startswith(query)
+        assert s.endswith(end)
+        return s[len(query):-len(end)]
+
 class Repository(RunWithEnv):
     """Represents a git repository."""
     def __init__(self, directory):
@@ -531,6 +647,8 @@ class Repository(RunWithEnv):
         self.__default_index = None
         self.__default_worktree = None
         self.__default_iw = None
+        self.__catfile = CatFileProcess(self)
+        self.__difftree = DiffTreeProcesses(self)
     env = property(lambda self: { 'GIT_DIR': self.__git_dir })
     @classmethod
     def default(cls):
@@ -580,14 +698,16 @@ class Repository(RunWithEnv):
     directory = property(lambda self: self.__git_dir)
     refs = property(lambda self: self.__refs)
     def cat_object(self, sha1):
-        return self.run(['git', 'cat-file', '-p', sha1]).raw_output()
-    def rev_parse(self, rev, discard_stderr = False):
+        return self.__catfile.cat_file(sha1)[1]
+    def rev_parse(self, rev, discard_stderr = False, object_type = 'commit'):
+        assert object_type in ('commit', 'tree', 'blob')
+        getter = getattr(self, 'get_' + object_type)
         try:
-            return self.get_commit(self.run(
-                    ['git', 'rev-parse', '%s^{commit}' % rev]
+            return getter(self.run(
+                    ['git', 'rev-parse', '%s^{%s}' % (rev, object_type)]
                     ).discard_stderr(discard_stderr).output_one_line())
         except run.RunException:
-            raise RepositoryException('%s: No such revision' % rev)
+            raise RepositoryException('%s: No such %s' % (rev, object_type))
     def get_blob(self, sha1):
         return self.__blobs[sha1]
     def get_tree(self, sha1):
@@ -613,7 +733,7 @@ class Repository(RunWithEnv):
         """Return a set of merge bases of two commits."""
         sha1_list = self.run(['git', 'merge-base', '--all',
                               commit1.sha1, commit2.sha1]).output_lines()
-        return set(self.get_commit(sha1) for sha1 in sha1_list)
+        return [self.get_commit(sha1) for sha1 in sha1_list]
     def describe(self, commit):
         """Use git describe --all on the given commit."""
         return self.run(['git', 'describe', '--all', commit.sha1]
@@ -655,8 +775,8 @@ class Repository(RunWithEnv):
         diff_opts = list(diff_opts)
         if binary and not '--binary' in diff_opts:
             diff_opts.append('--binary')
-        return self.run(['git', 'diff-tree', '-p'] + diff_opts
-                        + [t1.sha1, t2.sha1]).raw_output()
+        return self.__difftree.diff_trees(['-p'] + diff_opts,
+                                          t1.sha1, t2.sha1)
     def diff_tree_files(self, t1, t2):
         """Given two L{Tree}s C{t1} and C{t2}, iterate over all files for
         which they differ. For each file, yield a tuple with the old
@@ -666,8 +786,8 @@ class Repository(RunWithEnv):
         identical."""
         assert isinstance(t1, Tree)
         assert isinstance(t2, Tree)
-        i = iter(self.run(['git', 'diff-tree', '-r', '-z'] + [t1.sha1, t2.sha1]
-                          ).raw_output().split('\0'))
+        i = iter(self.__difftree.diff_trees(
+                ['-r', '-z'], t1.sha1, t2.sha1).split('\0'))
         try:
             while True:
                 x = i.next()
