@@ -14,14 +14,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 import sys, os, re
 from email.Utils import formatdate
 
-from stgit.exception import *
+from stgit.exception import StackException
 from stgit.utils import *
 from stgit.out import *
 from stgit.run import *
@@ -30,9 +29,6 @@ from stgit.config import config
 from shutil import copyfile
 from stgit.lib import git as libgit, stackupgrade
 
-# stack exception class
-class StackException(StgException):
-    pass
 
 class FilterUntil:
     def __init__(self):
