@@ -1,7 +1,7 @@
 """Common utility functions
 """
 
-import errno, os, os.path, re, sys
+import errno, os, os.path, re, sys, tempfile
 from stgit.exception import *
 from stgit.config import config
 from stgit.out import *
@@ -19,8 +19,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+along with this program; if not, see http://www.gnu.org/licenses/.
 """
 
 def mkdir_file(filename, mode):
@@ -189,6 +188,53 @@ def call_editor(filename):
         raise EditorException, 'editor failed, exit code: %d' % err
     out.done()
 
+def get_hook(repository, hook_name, extra_env={}):
+    hook_path = os.path.join(repository.directory, 'hooks', hook_name)
+    if not (os.path.isfile(hook_path) and os.access(hook_path, os.X_OK)):
+        return None
+
+    default_iw = repository.default_iw
+    prefix_dir = os.path.relpath(os.getcwd(), default_iw.cwd)
+    if prefix_dir == os.curdir:
+        prefix = ''
+    else:
+        prefix = os.path.join(prefix_dir, '')
+    extra_env = add_dict(extra_env, {'GIT_PREFIX': prefix})
+
+    def hook(*parameters):
+        argv = [hook_path]
+        argv.extend(parameters)
+
+        # On Windows, run the hook using "bash" explicitly
+        if os.name != 'posix':
+            argv.insert(0, 'bash')
+
+        default_iw.run(argv, extra_env).run()
+
+    hook.__name__ = hook_name
+    return hook
+
+def run_hook_on_string(hook, s, *args):
+    if hook is not None:
+        temp = tempfile.NamedTemporaryFile('wb', delete=False)
+        try:
+            try:
+                temp.write(s)
+            finally:
+                temp.close()
+
+            hook(temp.name, *args)
+
+            output = open(temp.name, 'rb')
+            try:
+                s = output.read()
+            finally:
+                output.close()
+        finally:
+            os.unlink(temp.name)
+
+    return s
+
 def edit_string(s, filename):
     f = file(filename, 'w')
     f.write(s)
@@ -253,13 +299,18 @@ def make_patch_name(msg, unacceptable, default_name = 'patch'):
 
 # any and all functions are builtin in Python 2.5 and higher, but not
 # in 2.4.
-if not 'any' in dir(__builtins__):
+if 'any' in dir(__builtins__):
+    any = getattr(__builtins__, 'any')
+else:
     def any(bools):
         for b in bools:
             if b:
                 return True
         return False
-if not 'all' in dir(__builtins__):
+
+if 'all' in dir(__builtins__):
+    all = getattr(__builtins__, 'all')
+else:
     def all(bools):
         for b in bools:
             if not b:
@@ -273,7 +324,9 @@ def add_sign_line(desc, sign_str, name, email):
     if sign_str in desc:
         return desc
     desc = desc.rstrip()
-    if not any(s in desc for s in ['\nSigned-off-by:', '\nAcked-by:']):
+    preamble, lastblank, lastpara = desc.rpartition('\n\n')
+    is_signoff = re.compile(r'[A-Z][a-z]*(-[A-Za-z][a-z]*)*: ').match
+    if not (lastblank and all(is_signoff(l) for l in lastpara.split('\n'))):
         desc = desc + '\n'
     return '%s\n%s\n' % (desc, sign_str)
 
