@@ -12,7 +12,7 @@ test_expect_success \
     '
     stg new foo -m foo &&
     echo foo > foo.txt &&
-    git add foo.txt &&
+    stg add foo.txt &&
     stg refresh
     '
 
@@ -47,7 +47,7 @@ test_expect_success \
     '
     stg new foo -m foo &&
     echo foo > foo.txt &&
-    git add foo.txt &&
+    stg add foo.txt &&
     stg refresh &&
     stg pop
     '
@@ -61,18 +61,30 @@ test_expect_success \
     '
 
 test_expect_success \
-    'Create two patches' \
+    'Create three patches' \
     '
     stg new foo -m foo &&
     echo foo > foo.txt &&
-    git add foo.txt &&
+    stg add foo.txt &&
     stg refresh &&
     stg new bar -m bar &&
     echo bar > bar.txt &&
-    git add bar.txt &&
+    stg add bar.txt &&
+    stg refresh &&
+    stg new baz -m baz &&
+    echo baz > baz.txt &&
+    stg add baz.txt &&
     stg refresh
     '
 
+test_expect_success \
+    'Try to delete a topmost patch with --top option' \
+    '
+    [ $(stg series --applied -c) -eq 3 ] &&
+    stg delete --top &&
+    [ $(stg series --applied -c) -eq 2 ]
+    '
+
 test_expect_success \
     'Try to delete a non-topmost applied patch' \
     '
@@ -87,12 +99,12 @@ test_expect_success \
     stg branch --create br &&
     stg new baz -m baz &&
     echo baz > baz.txt &&
-    git add baz.txt &&
+    stg add baz.txt &&
     stg refresh &&
     stg branch master &&
     stg new baz -m baz &&
     echo baz > baz.txt &&
-    git add baz.txt &&
+    stg add baz.txt &&
     stg refresh
     '
 
