@@ -5,7 +5,7 @@ test_description='Simple test cases for "stg reset"'
 . ./test-lib.sh
 
 # Ignore our own output files.
-cat > .git/info/exclude <<EOF
+cat >> .git/info/exclude <<EOF
 /expected.txt
 /actual.txt
 EOF
@@ -13,7 +13,7 @@ EOF
 test_expect_success 'Initialize StGit stack with three patches' '
     stg init &&
     echo 000 >> a &&
-    git add a &&
+    stg add a &&
     git commit -m a &&
     echo 111 >> a &&
     git commit -a -m p1 &&
@@ -25,7 +25,7 @@ test_expect_success 'Initialize StGit stack with three patches' '
 '
 
 cat > expected.txt <<EOF
-C a
+UU a
 EOF
 test_expect_success 'Pop middle patch, creating a conflict' '
     conflict stg pop p2 &&
@@ -47,7 +47,7 @@ test_expect_success 'Try to reset with --hard' '
     stg reset --hard master.stgit^~1 &&
     stg status a > actual.txt &&
     test_cmp expected.txt actual.txt &&
-    test "$(echo $(stg series))" = "> p1 - p2 - p3"
+    test "$(echo $(stg series))" = "+ p1 + p2 > p3"
 '
 
 test_done
